import { __decorate, __metadata, __param } from 'tslib';
import { EventEmitter, Input, Output, ViewChild, ElementRef, Component, InjectionToken, Optional, Inject, Injectable, forwardRef, ComponentFactoryResolver, ViewContainerRef, TemplateRef, ContentChild, NgModule } from '@angular/core';
import { debounceTime } from 'rxjs/operators';
import { fromEvent, Subscription } from 'rxjs';
import { DataTableFooterTemplateDirective, DatatableComponent, DatatableFooterDirective, NgxDatatableModule } from '@swimlane/ngx-datatable';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

let DatatablePagerComponent = class DatatablePagerComponent {
    constructor() {
        this.linage = true;
        this.displayBothEnds = true;
        this.pageNumber = true;
        this.pageJumpTime = 1000;
        this.change = new EventEmitter();
        this.pageChange = new EventEmitter();
        this.maxPage = new EventEmitter();
        this.pageSizeColumn = true;
        this._page = 1;
        this._count = 0;
        this._size = 0;
    }
    set size(val) {
        this._size = val;
        this.pages = this.calcPages();
    }
    get size() {
        return this._size;
    }
    set count(val) {
        this._count = val;
        this.pages = this.calcPages();
    }
    get count() {
        return this._count;
    }
    set page(val) {
        if (val) {
            this._page = val;
            this.pages = this.calcPages();
        }
    }
    get page() {
        return this._page;
    }
    get totalPages() {
        const count = this.size < 1 ? 1 : Math.ceil(this.count / this.size);
        return Math.max(count || 0, 1);
    }
    ngOnInit() { }
    ngAfterViewInit() {
        this.inputEvent = fromEvent(this.customerInput.nativeElement, 'input')
            .pipe(debounceTime(this.pageJumpTime))
            .subscribe((event) => {
            let value;
            if (event.target.value) {
                value = Number(event.target.value);
                if (value < 1) {
                    value = 1;
                    this.customerInput.nativeElement.value = 1;
                }
                else if (value > this.totalPages) {
                    value = this.totalPages;
                    this.customerInput.nativeElement.value = this.totalPages;
                    this.maxPage.emit(this.totalPages);
                }
                this.page = value;
                this.selectPage(Math.round(value));
            }
        });
    }
    canPrevious() {
        return this.page > 1;
    }
    canNext() {
        return this.page < this.totalPages;
    }
    prevPage() {
        this.selectPage(this.page - 1);
    }
    nextPage() {
        this.selectPage(this.page + 1);
    }
    firstPage() {
        if (this.canPrevious()) {
            this.selectPage(1);
        }
    }
    lastPage() {
        if (this.canNext()) {
            this.selectPage(this.totalPages);
        }
    }
    selectPage(page, changePageSize) {
        if (changePageSize) {
            if (page > 0 && page <= this.totalPages) {
                this.page = page;
                this.currentOffset = page;
                this.change.emit({ page });
            }
        }
        else {
            if (page > 0 && page <= this.totalPages) {
                this.page = page;
                this.currentOffset = page;
                this.change.emit({ page });
            }
        }
    }
    calcPages(page) {
        const pages = [];
        let startPage = 1;
        let endPage = this.totalPages;
        const maxSize = 5;
        const isMaxSized = maxSize < this.totalPages;
        page = page || this.page;
        if (isMaxSized) {
            startPage = (Math.ceil(page / maxSize) - 1) * maxSize + 1;
            endPage = Math.min(startPage + maxSize - 1, this.totalPages);
        }
        for (let num = startPage; num <= endPage; num++) {
            pages.push({ number: num, text: num });
        }
        return pages;
    }
    blurHandel() {
        this.customerInput.nativeElement.value = this.page;
    }
    changePageSize(pageSize) {
        this.datatable.limit = pageSize;
        this.selectPage(1, 'changePageSize');
    }
    keyDownHandel(event) {
        if (this.customerInput.nativeElement.value) {
            this.prveOffset = Number(this.customerInput.nativeElement.value);
        }
        if ((event.keyCode < 48 && event.keyCode !== 8) ||
            (event.keyCode > 57 && event.keyCode < 96) ||
            event.keyCode > 105) {
            return false;
        }
    }
    ngOnDestroy() {
        this.inputEvent.unsubscribe();
    }
};
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatablePagerComponent.prototype, "pagerLeftArrowIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatablePagerComponent.prototype, "pagerRightArrowIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatablePagerComponent.prototype, "pagerPreviousIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatablePagerComponent.prototype, "pagerNextIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DatatablePagerComponent.prototype, "pageSizes", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DatatablePagerComponent.prototype, "datatable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatablePagerComponent.prototype, "linage", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatablePagerComponent.prototype, "displayBothEnds", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatablePagerComponent.prototype, "pageNumber", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], DatatablePagerComponent.prototype, "pageJumpTime", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DatatablePagerComponent.prototype, "labels", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], DatatablePagerComponent.prototype, "size", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], DatatablePagerComponent.prototype, "count", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], DatatablePagerComponent.prototype, "page", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DatatablePagerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DatatablePagerComponent.prototype, "pageChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DatatablePagerComponent.prototype, "maxPage", void 0);
__decorate([
    ViewChild('customerInput', { static: true }),
    __metadata("design:type", ElementRef)
], DatatablePagerComponent.prototype, "customerInput", void 0);
DatatablePagerComponent = __decorate([
    Component({
        selector: 'app-datatable-pager',
        template: ` <ul class="pager">
    <li
      class="page-size-continer"
      *ngIf="linage"
      (click)="pageSizeColumn = !pageSizeColumn"
      (mouseleave)="pageSizeColumn = true"
    >
      <span>{{ size }} {{ labels.line }}/{{ labels.page }}</span>
      <span
        class="fa"
        [ngClass]="{
          'fa-angle-up': pageSizeColumn,
          'fa-angle-down': !pageSizeColumn
        }"
      ></span>
      <ul [hidden]="pageSizeColumn" class="page-size-content">
        <li
          *ngFor="let ps of pageSizes"
          (click)="changePageSize(ps)"
          [ngClass]="{ 'page-size-column-active': size === ps }"
        >
          {{ ps }} {{ labels.line }}/{{ labels.page }}
        </li>
      </ul>
    </li>
    <li *ngIf="displayBothEnds" [class.disabled]="!canPrevious()">
      <a (click)="firstPage()">
        <i class="{{ pagerPreviousIcon }}"></i>
      </a>
    </li>
    <li [class.disabled]="!canPrevious()">
      <a (click)="prevPage()">
        <i class="{{ pagerLeftArrowIcon }}"></i>
      </a>
    </li>
    <li class="pages" *ngFor="let pg of pages" [class.active]="pg.number === page">
      <a *ngIf="pageNumber" (click)="selectPage(pg.number)">
        {{ pg.text }}
      </a>
    </li>
    <li [class.disabled]="!canNext()">
      <a (click)="nextPage()">
        <i class="{{ pagerRightArrowIcon }}"></i>
      </a>
    </li>
    <li *ngIf="displayBothEnds" [class.disabled]="!canNext()">
      <a (click)="lastPage()">
        <i class="{{ pagerNextIcon }}"></i>
      </a>
    </li>
    <li [ngStyle]="{ position: 'relative' }">
      <span>{{ labels.jumpTo }}</span>
      <input
        #customerInput
        class="lz-jump-page"
        type="number"
        title=" "
        rows="2"
        [min]="1"
        [ngModel]="page"
        (keydown)="keyDownHandel($event)"
        (blur)="blurHandel()"
      />{{ labels.page }}
    </li>
  </ul>`,
        styles: [`
      .page-size-continer {
        position: relative;
        min-width: 80px;
        height: 26px;
        line-height: 26px;
        text-align: center;
        border-radius: 2px;
        cursor: pointer;
        padding: 0 10px !important;
      }
      .page-size-continer:hover {
        background-color: rgba(158, 158, 158, 0.2);
      }
      .page-size-continer .page-size-content {
        position: absolute;
        bottom: 24px;
        left: 0;
        padding: 0;
        background: #fff;
        border-radius: 4px;
        box-shadow: 0 0 15px 1px rgba(113, 106, 202, 0.2);
        z-index: 11;
      }
      .page-size-continer .page-size-content li {
        width: 100%;
        padding: 4px 0;
      }
      .page-size-continer .page-size-content li:hover {
        background-color: rgba(158, 158, 158, 0.2);
      }
      .page-size-continer .page-size-content .page-size-column-active {
        color: #409eff;
      }
      input[type='number']::-webkit-inner-spin-button,
      input[type='number']::-webkit-outer-spin-button {
        -webkit-appearance: none;
      }
      .lz-jump-page {
        display: inline-block;
        width: 50px;
        border-radius: 2px;
        margin-right: 6px;
        padding-left: 4px;
        border: solid 1px #ebedf2;
      }
      input[type='number'] {
        -moz-appearance: textfield;
      }
    `]
    })
], DatatablePagerComponent);

const Ngx_Datatable_Footer_Option = new InjectionToken('Ngx_Datatable_Footer_Option');
function FooterOptionProvider(options = {}) {
    return {
        provide: Ngx_Datatable_Footer_Option,
        useValue: options
    };
}

let FooterConfigurationService = class FooterConfigurationService {
    constructor(footerOptions, translate) {
        this.footerOptions = footerOptions;
        this.translate = translate;
        this.defaultLabels = {
            current: '当前 ',
            line: '行',
            page: '页',
            jumpTo: '跳转到',
        };
        this._subs = new Subscription();
        this.update();
        this._subs.add(this.translate.onLangChange.subscribe((lang) => {
            setTimeout(() => {
                this.update();
            }, 0);
        }));
    }
    ngOnDestroy() {
        this._subs.unsubscribe();
    }
    update() {
        this._language = localStorage.getItem('lang');
        if (this._language === 'zh-CN' || !this._language) {
            this.labels = this.defaultLabels;
        }
        else {
            if (this._language) {
                if (this._language) {
                    this._subs.add(this.translate.get('ngxFooterSettings.labels').subscribe((translations) => {
                        this.labels = translations;
                    }));
                }
            }
        }
    }
};
FooterConfigurationService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [Ngx_Datatable_Footer_Option,] }] },
    { type: TranslateService }
];
FooterConfigurationService = __decorate([
    Injectable(),
    __param(0, Optional()), __param(0, Inject(Ngx_Datatable_Footer_Option)),
    __metadata("design:paramtypes", [Object, TranslateService])
], FooterConfigurationService);

var DatatableFooterComponent_1;
function provideParent(component, parentType) {
    return { provide: parentType, useExisting: forwardRef(() => component) };
}
let DatatableFooterComponent = DatatableFooterComponent_1 = class DatatableFooterComponent {
    constructor(config, componentFactoryResolver, viewContainerRef) {
        this.config = config;
        this.componentFactoryResolver = componentFactoryResolver;
        this.viewContainerRef = viewContainerRef;
        this.pagerLeftArrowIcon = 'fa fa-angle-left';
        this.pagerRightArrowIcon = 'fa fa-angle-right';
        this.pagerPreviousIcon = 'fa fa-step-backward';
        this.pagerNextIcon = 'fa fa-step-forward';
        this.pageSizes = [10, 20, 30, 40, 50];
        this.totalNumber = true;
        this.linage = true;
        this.displayBothEnds = true;
        this.pageNumber = true;
        this.pageJumpTime = 1000;
        this.pageChange = new EventEmitter();
        this.maxPage = new EventEmitter();
    }
    get template() {
        return this._templateInput || this._templateQueryDefault || this._templateQuery;
    }
    set datatable(val) {
        this._datatable = val;
    }
    get datatable() {
        return this._datatable;
    }
    ngOnInit() {
        if (this.config.footerOptions && this.config.footerOptions.pageStatics) {
            const componentFactory = this.componentFactoryResolver.resolveComponentFactory(this.config.footerOptions.pageStatics);
            // 因为默认创建组件时，获取不到组件的templateRef,所以改用这种方式
            this._pageStaticsComponentRef = this.viewContainerRef.createComponent(componentFactory);
        }
    }
    ngAfterViewInit() {
        if (this._pageStaticsComponentRef) {
            this.pageStaticsTemplateRef = this._pageStaticsComponentRef.instance.templateRef;
            // 先移除，目前看不移除也不会造成内存问题
            this.viewContainerRef.remove(this.viewContainerRef.indexOf(this._pageStaticsComponentRef.hostView));
            this._pageStaticsComponentRef.destroy();
        }
    }
    onFooterPage(event) {
        if (typeof event.page === 'number') {
            this.datatable.onFooterPage(event);
        }
    }
    emitPage(event) {
        if (typeof event.page === 'number') {
            this.pageChange.emit(event);
        }
    }
    emitMaxPage(page) {
        this.maxPage.emit(page);
    }
};
DatatableFooterComponent.ctorParameters = () => [
    { type: FooterConfigurationService },
    { type: ComponentFactoryResolver },
    { type: ViewContainerRef }
];
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatableFooterComponent.prototype, "pagerLeftArrowIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatableFooterComponent.prototype, "pagerRightArrowIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatableFooterComponent.prototype, "pagerPreviousIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], DatatableFooterComponent.prototype, "pagerNextIcon", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DatatableFooterComponent.prototype, "pageSizes", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatableFooterComponent.prototype, "totalNumber", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatableFooterComponent.prototype, "linage", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatableFooterComponent.prototype, "displayBothEnds", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DatatableFooterComponent.prototype, "pageNumber", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], DatatableFooterComponent.prototype, "page", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], DatatableFooterComponent.prototype, "pageJumpTime", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], DatatableFooterComponent.prototype, "pageChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], DatatableFooterComponent.prototype, "maxPage", void 0);
__decorate([
    Input('template'),
    __metadata("design:type", TemplateRef)
], DatatableFooterComponent.prototype, "_templateInput", void 0);
__decorate([
    ViewChild(DataTableFooterTemplateDirective, { static: true, read: TemplateRef }),
    __metadata("design:type", TemplateRef)
], DatatableFooterComponent.prototype, "_templateQuery", void 0);
__decorate([
    ContentChild(DataTableFooterTemplateDirective, { static: true, read: TemplateRef }),
    __metadata("design:type", TemplateRef)
], DatatableFooterComponent.prototype, "_templateQueryDefault", void 0);
__decorate([
    Input(),
    __metadata("design:type", DatatableComponent),
    __metadata("design:paramtypes", [DatatableComponent])
], DatatableFooterComponent.prototype, "datatable", null);
DatatableFooterComponent = DatatableFooterComponent_1 = __decorate([
    Component({
        selector: 'zr-ngx-datatable-footer,ngx-datatable-footer',
        template: "<ng-template\n  ngx-datatable-footer-template\n  let-rowCount=\"rowCount\"\n  let-pageSize=\"pageSize\"\n  let-selectedCount=\"selectedCount\"\n  let-curPage=\"curPage\"\n  let-offset=\"offset\"\n>\n  <div\n    class=\"page-count\"\n    *ngIf=\"!pageStaticsTemplateRef && rowCount > 0 && totalNumber\"\n    [innerHTML]=\"\n      config.labels.current +\n      ((offset || 0) * pageSize + 1) +\n      ' - ' +\n      ((offset + 1) * pageSize > rowCount ? rowCount : (offset + 1 || 1) * pageSize) +\n      ' / ' +\n      rowCount +\n      config.labels.line\n    \"\n  ></div>\n\n  <ng-container\n    *ngIf=\"pageStaticsTemplateRef\"\n    [ngTemplateOutlet]=\"pageStaticsTemplateRef\"\n    [ngTemplateOutletContext]=\"{\n      rowCount: rowCount,\n      pageSize: pageSize,\n      selectedCount: selectedCount,\n      curPage: curPage,\n      offset: offset,\n      config: config\n    }\"\n  ></ng-container>\n\n  <app-datatable-pager\n    *ngIf=\"rowCount > 0\"\n    [displayBothEnds]=\"displayBothEnds\"\n    [pageNumber]=\"pageNumber\"\n    [pageSizes]=\"pageSizes\"\n    [pagerPreviousIcon]=\"pagerPreviousIcon\"\n    [pagerNextIcon]=\"pagerNextIcon\"\n    [pagerLeftArrowIcon]=\"pagerLeftArrowIcon\"\n    [pagerRightArrowIcon]=\"pagerRightArrowIcon\"\n    [page]=\"curPage\"\n    [size]=\"pageSize\"\n    [pageJumpTime]=\"pageJumpTime\"\n    [datatable]=\"datatable\"\n    [count]=\"rowCount\"\n    [labels]=\"config.labels\"\n    (change)=\"onFooterPage($event); emitPage($event)\"\n    (pageChange)=\"emitPage($event)\"\n    (maxPage)=\"emitMaxPage($event)\"\n    class=\"datatable-pager\"\n  ></app-datatable-pager>\n</ng-template>\n",
        providers: [provideParent(DatatableFooterComponent_1, DatatableFooterDirective)]
    }),
    __metadata("design:paramtypes", [FooterConfigurationService,
        ComponentFactoryResolver,
        ViewContainerRef])
], DatatableFooterComponent);

var NgxDatatableFooterModule_1;
let NgxDatatableFooterModule = NgxDatatableFooterModule_1 = class NgxDatatableFooterModule {
    static forRoot(footerOptions) {
        return {
            ngModule: NgxDatatableFooterModule_1,
            providers: [FooterOptionProvider(footerOptions)],
        };
    }
};
NgxDatatableFooterModule = NgxDatatableFooterModule_1 = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, TranslateModule, NgxDatatableModule],
        declarations: [DatatablePagerComponent, DatatableFooterComponent],
        exports: [DatatablePagerComponent, DatatableFooterComponent],
        providers: [FooterConfigurationService],
    })
], NgxDatatableFooterModule);

/*
 * Public API Surface of ngx-datatable-footer
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DatatableFooterComponent, DatatablePagerComponent, FooterConfigurationService, FooterOptionProvider, NgxDatatableFooterModule, Ngx_Datatable_Footer_Option, provideParent };
//# sourceMappingURL=ngx-datatable-footer.js.map
