import { __decorate, __metadata, __param } from 'tslib';
import { EventEmitter, Input, Output, ViewChild, ElementRef, Component, InjectionToken, Optional, Inject, Injectable, forwardRef, ComponentFactoryResolver, ViewContainerRef, TemplateRef, ContentChild, NgModule } from '@angular/core';
import { debounceTime } from 'rxjs/operators';
import { fromEvent, Subscription } from 'rxjs';
import { DataTableFooterTemplateDirective, DatatableComponent, DatatableFooterDirective, NgxDatatableModule } from '@swimlane/ngx-datatable';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

var DatatablePagerComponent = /** @class */ (function () {
    function DatatablePagerComponent() {
        this.linage = true;
        this.displayBothEnds = true;
        this.pageNumber = true;
        this.pageJumpTime = 1000;
        this.change = new EventEmitter();
        this.pageChange = new EventEmitter();
        this.maxPage = new EventEmitter();
        this.pageSizeColumn = true;
        this._page = 1;
        this._count = 0;
        this._size = 0;
    }
    Object.defineProperty(DatatablePagerComponent.prototype, "size", {
        get: function () {
            return this._size;
        },
        set: function (val) {
            this._size = val;
            this.pages = this.calcPages();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatatablePagerComponent.prototype, "count", {
        get: function () {
            return this._count;
        },
        set: function (val) {
            this._count = val;
            this.pages = this.calcPages();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatatablePagerComponent.prototype, "page", {
        get: function () {
            return this._page;
        },
        set: function (val) {
            if (val) {
                this._page = val;
                this.pages = this.calcPages();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatatablePagerComponent.prototype, "totalPages", {
        get: function () {
            var count = this.size < 1 ? 1 : Math.ceil(this.count / this.size);
            return Math.max(count || 0, 1);
        },
        enumerable: true,
        configurable: true
    });
    DatatablePagerComponent.prototype.ngOnInit = function () { };
    DatatablePagerComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.inputEvent = fromEvent(this.customerInput.nativeElement, 'input')
            .pipe(debounceTime(this.pageJumpTime))
            .subscribe(function (event) {
            var value;
            if (event.target.value) {
                value = Number(event.target.value);
                if (value < 1) {
                    value = 1;
                    _this.customerInput.nativeElement.value = 1;
                }
                else if (value > _this.totalPages) {
                    value = _this.totalPages;
                    _this.customerInput.nativeElement.value = _this.totalPages;
                    _this.maxPage.emit(_this.totalPages);
                }
                _this.page = value;
                _this.selectPage(Math.round(value));
            }
        });
    };
    DatatablePagerComponent.prototype.canPrevious = function () {
        return this.page > 1;
    };
    DatatablePagerComponent.prototype.canNext = function () {
        return this.page < this.totalPages;
    };
    DatatablePagerComponent.prototype.prevPage = function () {
        this.selectPage(this.page - 1);
    };
    DatatablePagerComponent.prototype.nextPage = function () {
        this.selectPage(this.page + 1);
    };
    DatatablePagerComponent.prototype.firstPage = function () {
        if (this.canPrevious()) {
            this.selectPage(1);
        }
    };
    DatatablePagerComponent.prototype.lastPage = function () {
        if (this.canNext()) {
            this.selectPage(this.totalPages);
        }
    };
    DatatablePagerComponent.prototype.selectPage = function (page, changePageSize) {
        if (changePageSize) {
            if (page > 0 && page <= this.totalPages) {
                this.page = page;
                this.currentOffset = page;
                this.change.emit({ page: page });
            }
        }
        else {
            if (page > 0 && page <= this.totalPages) {
                this.page = page;
                this.currentOffset = page;
                this.change.emit({ page: page });
            }
        }
    };
    DatatablePagerComponent.prototype.calcPages = function (page) {
        var pages = [];
        var startPage = 1;
        var endPage = this.totalPages;
        var maxSize = 5;
        var isMaxSized = maxSize < this.totalPages;
        page = page || this.page;
        if (isMaxSized) {
            startPage = (Math.ceil(page / maxSize) - 1) * maxSize + 1;
            endPage = Math.min(startPage + maxSize - 1, this.totalPages);
        }
        for (var num = startPage; num <= endPage; num++) {
            pages.push({ number: num, text: num });
        }
        return pages;
    };
    DatatablePagerComponent.prototype.blurHandel = function () {
        this.customerInput.nativeElement.value = this.page;
    };
    DatatablePagerComponent.prototype.changePageSize = function (pageSize) {
        this.datatable.limit = pageSize;
        this.selectPage(1, 'changePageSize');
    };
    DatatablePagerComponent.prototype.keyDownHandel = function (event) {
        if (this.customerInput.nativeElement.value) {
            this.prveOffset = Number(this.customerInput.nativeElement.value);
        }
        if ((event.keyCode < 48 && event.keyCode !== 8) ||
            (event.keyCode > 57 && event.keyCode < 96) ||
            event.keyCode > 105) {
            return false;
        }
    };
    DatatablePagerComponent.prototype.ngOnDestroy = function () {
        this.inputEvent.unsubscribe();
    };
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatablePagerComponent.prototype, "pagerLeftArrowIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatablePagerComponent.prototype, "pagerRightArrowIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatablePagerComponent.prototype, "pagerPreviousIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatablePagerComponent.prototype, "pagerNextIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DatatablePagerComponent.prototype, "pageSizes", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DatatablePagerComponent.prototype, "datatable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatablePagerComponent.prototype, "linage", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatablePagerComponent.prototype, "displayBothEnds", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatablePagerComponent.prototype, "pageNumber", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DatatablePagerComponent.prototype, "pageJumpTime", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DatatablePagerComponent.prototype, "labels", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], DatatablePagerComponent.prototype, "size", null);
    __decorate([
        Input(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], DatatablePagerComponent.prototype, "count", null);
    __decorate([
        Input(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], DatatablePagerComponent.prototype, "page", null);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DatatablePagerComponent.prototype, "change", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DatatablePagerComponent.prototype, "pageChange", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DatatablePagerComponent.prototype, "maxPage", void 0);
    __decorate([
        ViewChild('customerInput', { static: true }),
        __metadata("design:type", ElementRef)
    ], DatatablePagerComponent.prototype, "customerInput", void 0);
    DatatablePagerComponent = __decorate([
        Component({
            selector: 'app-datatable-pager',
            template: " <ul class=\"pager\">\n    <li\n      class=\"page-size-continer\"\n      *ngIf=\"linage\"\n      (click)=\"pageSizeColumn = !pageSizeColumn\"\n      (mouseleave)=\"pageSizeColumn = true\"\n    >\n      <span>{{ size }} {{ labels.line }}/{{ labels.page }}</span>\n      <span\n        class=\"fa\"\n        [ngClass]=\"{\n          'fa-angle-up': pageSizeColumn,\n          'fa-angle-down': !pageSizeColumn\n        }\"\n      ></span>\n      <ul [hidden]=\"pageSizeColumn\" class=\"page-size-content\">\n        <li\n          *ngFor=\"let ps of pageSizes\"\n          (click)=\"changePageSize(ps)\"\n          [ngClass]=\"{ 'page-size-column-active': size === ps }\"\n        >\n          {{ ps }} {{ labels.line }}/{{ labels.page }}\n        </li>\n      </ul>\n    </li>\n    <li *ngIf=\"displayBothEnds\" [class.disabled]=\"!canPrevious()\">\n      <a (click)=\"firstPage()\">\n        <i class=\"{{ pagerPreviousIcon }}\"></i>\n      </a>\n    </li>\n    <li [class.disabled]=\"!canPrevious()\">\n      <a (click)=\"prevPage()\">\n        <i class=\"{{ pagerLeftArrowIcon }}\"></i>\n      </a>\n    </li>\n    <li class=\"pages\" *ngFor=\"let pg of pages\" [class.active]=\"pg.number === page\">\n      <a *ngIf=\"pageNumber\" (click)=\"selectPage(pg.number)\">\n        {{ pg.text }}\n      </a>\n    </li>\n    <li [class.disabled]=\"!canNext()\">\n      <a (click)=\"nextPage()\">\n        <i class=\"{{ pagerRightArrowIcon }}\"></i>\n      </a>\n    </li>\n    <li *ngIf=\"displayBothEnds\" [class.disabled]=\"!canNext()\">\n      <a (click)=\"lastPage()\">\n        <i class=\"{{ pagerNextIcon }}\"></i>\n      </a>\n    </li>\n    <li [ngStyle]=\"{ position: 'relative' }\">\n      <span>{{ labels.jumpTo }}</span>\n      <input\n        #customerInput\n        class=\"lz-jump-page\"\n        type=\"number\"\n        title=\" \"\n        rows=\"2\"\n        [min]=\"1\"\n        [ngModel]=\"page\"\n        (keydown)=\"keyDownHandel($event)\"\n        (blur)=\"blurHandel()\"\n      />{{ labels.page }}\n    </li>\n  </ul>",
            styles: ["\n      .page-size-continer {\n        position: relative;\n        min-width: 80px;\n        height: 26px;\n        line-height: 26px;\n        text-align: center;\n        border-radius: 2px;\n        cursor: pointer;\n        padding: 0 10px !important;\n      }\n      .page-size-continer:hover {\n        background-color: rgba(158, 158, 158, 0.2);\n      }\n      .page-size-continer .page-size-content {\n        position: absolute;\n        bottom: 24px;\n        left: 0;\n        padding: 0;\n        background: #fff;\n        border-radius: 4px;\n        box-shadow: 0 0 15px 1px rgba(113, 106, 202, 0.2);\n        z-index: 11;\n      }\n      .page-size-continer .page-size-content li {\n        width: 100%;\n        padding: 4px 0;\n      }\n      .page-size-continer .page-size-content li:hover {\n        background-color: rgba(158, 158, 158, 0.2);\n      }\n      .page-size-continer .page-size-content .page-size-column-active {\n        color: #409eff;\n      }\n      input[type='number']::-webkit-inner-spin-button,\n      input[type='number']::-webkit-outer-spin-button {\n        -webkit-appearance: none;\n      }\n      .lz-jump-page {\n        display: inline-block;\n        width: 50px;\n        border-radius: 2px;\n        margin-right: 6px;\n        padding-left: 4px;\n        border: solid 1px #ebedf2;\n      }\n      input[type='number'] {\n        -moz-appearance: textfield;\n      }\n    "]
        })
    ], DatatablePagerComponent);
    return DatatablePagerComponent;
}());

var Ngx_Datatable_Footer_Option = new InjectionToken('Ngx_Datatable_Footer_Option');
function FooterOptionProvider(options) {
    if (options === void 0) { options = {}; }
    return {
        provide: Ngx_Datatable_Footer_Option,
        useValue: options
    };
}

var FooterConfigurationService = /** @class */ (function () {
    function FooterConfigurationService(footerOptions, translate) {
        var _this = this;
        this.footerOptions = footerOptions;
        this.translate = translate;
        this.defaultLabels = {
            current: '当前 ',
            line: '行',
            page: '页',
            jumpTo: '跳转到',
        };
        this._subs = new Subscription();
        this.update();
        this._subs.add(this.translate.onLangChange.subscribe(function (lang) {
            setTimeout(function () {
                _this.update();
            }, 0);
        }));
    }
    FooterConfigurationService.prototype.ngOnDestroy = function () {
        this._subs.unsubscribe();
    };
    FooterConfigurationService.prototype.update = function () {
        var _this = this;
        this._language = localStorage.getItem('lang');
        if (this._language === 'zh-CN' || !this._language) {
            this.labels = this.defaultLabels;
        }
        else {
            if (this._language) {
                if (this._language) {
                    this._subs.add(this.translate.get('ngxFooterSettings.labels').subscribe(function (translations) {
                        _this.labels = translations;
                    }));
                }
            }
        }
    };
    FooterConfigurationService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [Ngx_Datatable_Footer_Option,] }] },
        { type: TranslateService }
    ]; };
    FooterConfigurationService = __decorate([
        Injectable(),
        __param(0, Optional()), __param(0, Inject(Ngx_Datatable_Footer_Option)),
        __metadata("design:paramtypes", [Object, TranslateService])
    ], FooterConfigurationService);
    return FooterConfigurationService;
}());

function provideParent(component, parentType) {
    return { provide: parentType, useExisting: forwardRef(function () { return component; }) };
}
var DatatableFooterComponent = /** @class */ (function () {
    function DatatableFooterComponent(config, componentFactoryResolver, viewContainerRef) {
        this.config = config;
        this.componentFactoryResolver = componentFactoryResolver;
        this.viewContainerRef = viewContainerRef;
        this.pagerLeftArrowIcon = 'fa fa-angle-left';
        this.pagerRightArrowIcon = 'fa fa-angle-right';
        this.pagerPreviousIcon = 'fa fa-step-backward';
        this.pagerNextIcon = 'fa fa-step-forward';
        this.pageSizes = [10, 20, 30, 40, 50];
        this.totalNumber = true;
        this.linage = true;
        this.displayBothEnds = true;
        this.pageNumber = true;
        this.pageJumpTime = 1000;
        this.pageChange = new EventEmitter();
        this.maxPage = new EventEmitter();
    }
    DatatableFooterComponent_1 = DatatableFooterComponent;
    Object.defineProperty(DatatableFooterComponent.prototype, "template", {
        get: function () {
            return this._templateInput || this._templateQueryDefault || this._templateQuery;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DatatableFooterComponent.prototype, "datatable", {
        get: function () {
            return this._datatable;
        },
        set: function (val) {
            this._datatable = val;
        },
        enumerable: true,
        configurable: true
    });
    DatatableFooterComponent.prototype.ngOnInit = function () {
        if (this.config.footerOptions && this.config.footerOptions.pageStatics) {
            var componentFactory = this.componentFactoryResolver.resolveComponentFactory(this.config.footerOptions.pageStatics);
            // 因为默认创建组件时，获取不到组件的templateRef,所以改用这种方式
            this._pageStaticsComponentRef = this.viewContainerRef.createComponent(componentFactory);
        }
    };
    DatatableFooterComponent.prototype.ngAfterViewInit = function () {
        if (this._pageStaticsComponentRef) {
            this.pageStaticsTemplateRef = this._pageStaticsComponentRef.instance.templateRef;
            // 先移除，目前看不移除也不会造成内存问题
            this.viewContainerRef.remove(this.viewContainerRef.indexOf(this._pageStaticsComponentRef.hostView));
            this._pageStaticsComponentRef.destroy();
        }
    };
    DatatableFooterComponent.prototype.onFooterPage = function (event) {
        if (typeof event.page === 'number') {
            this.datatable.onFooterPage(event);
        }
    };
    DatatableFooterComponent.prototype.emitPage = function (event) {
        if (typeof event.page === 'number') {
            this.pageChange.emit(event);
        }
    };
    DatatableFooterComponent.prototype.emitMaxPage = function (page) {
        this.maxPage.emit(page);
    };
    var DatatableFooterComponent_1;
    DatatableFooterComponent.ctorParameters = function () { return [
        { type: FooterConfigurationService },
        { type: ComponentFactoryResolver },
        { type: ViewContainerRef }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatableFooterComponent.prototype, "pagerLeftArrowIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatableFooterComponent.prototype, "pagerRightArrowIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatableFooterComponent.prototype, "pagerPreviousIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DatatableFooterComponent.prototype, "pagerNextIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DatatableFooterComponent.prototype, "pageSizes", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatableFooterComponent.prototype, "totalNumber", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatableFooterComponent.prototype, "linage", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatableFooterComponent.prototype, "displayBothEnds", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DatatableFooterComponent.prototype, "pageNumber", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DatatableFooterComponent.prototype, "page", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DatatableFooterComponent.prototype, "pageJumpTime", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DatatableFooterComponent.prototype, "pageChange", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DatatableFooterComponent.prototype, "maxPage", void 0);
    __decorate([
        Input('template'),
        __metadata("design:type", TemplateRef)
    ], DatatableFooterComponent.prototype, "_templateInput", void 0);
    __decorate([
        ViewChild(DataTableFooterTemplateDirective, { static: true, read: TemplateRef }),
        __metadata("design:type", TemplateRef)
    ], DatatableFooterComponent.prototype, "_templateQuery", void 0);
    __decorate([
        ContentChild(DataTableFooterTemplateDirective, { static: true, read: TemplateRef }),
        __metadata("design:type", TemplateRef)
    ], DatatableFooterComponent.prototype, "_templateQueryDefault", void 0);
    __decorate([
        Input(),
        __metadata("design:type", DatatableComponent),
        __metadata("design:paramtypes", [DatatableComponent])
    ], DatatableFooterComponent.prototype, "datatable", null);
    DatatableFooterComponent = DatatableFooterComponent_1 = __decorate([
        Component({
            selector: 'zr-ngx-datatable-footer,ngx-datatable-footer',
            template: "<ng-template\n  ngx-datatable-footer-template\n  let-rowCount=\"rowCount\"\n  let-pageSize=\"pageSize\"\n  let-selectedCount=\"selectedCount\"\n  let-curPage=\"curPage\"\n  let-offset=\"offset\"\n>\n  <div\n    class=\"page-count\"\n    *ngIf=\"!pageStaticsTemplateRef && rowCount > 0 && totalNumber\"\n    [innerHTML]=\"\n      config.labels.current +\n      ((offset || 0) * pageSize + 1) +\n      ' - ' +\n      ((offset + 1) * pageSize > rowCount ? rowCount : (offset + 1 || 1) * pageSize) +\n      ' / ' +\n      rowCount +\n      config.labels.line\n    \"\n  ></div>\n\n  <ng-container\n    *ngIf=\"pageStaticsTemplateRef\"\n    [ngTemplateOutlet]=\"pageStaticsTemplateRef\"\n    [ngTemplateOutletContext]=\"{\n      rowCount: rowCount,\n      pageSize: pageSize,\n      selectedCount: selectedCount,\n      curPage: curPage,\n      offset: offset,\n      config: config\n    }\"\n  ></ng-container>\n\n  <app-datatable-pager\n    *ngIf=\"rowCount > 0\"\n    [displayBothEnds]=\"displayBothEnds\"\n    [pageNumber]=\"pageNumber\"\n    [pageSizes]=\"pageSizes\"\n    [pagerPreviousIcon]=\"pagerPreviousIcon\"\n    [pagerNextIcon]=\"pagerNextIcon\"\n    [pagerLeftArrowIcon]=\"pagerLeftArrowIcon\"\n    [pagerRightArrowIcon]=\"pagerRightArrowIcon\"\n    [page]=\"curPage\"\n    [size]=\"pageSize\"\n    [pageJumpTime]=\"pageJumpTime\"\n    [datatable]=\"datatable\"\n    [count]=\"rowCount\"\n    [labels]=\"config.labels\"\n    (change)=\"onFooterPage($event); emitPage($event)\"\n    (pageChange)=\"emitPage($event)\"\n    (maxPage)=\"emitMaxPage($event)\"\n    class=\"datatable-pager\"\n  ></app-datatable-pager>\n</ng-template>\n",
            providers: [provideParent(DatatableFooterComponent_1, DatatableFooterDirective)]
        }),
        __metadata("design:paramtypes", [FooterConfigurationService,
            ComponentFactoryResolver,
            ViewContainerRef])
    ], DatatableFooterComponent);
    return DatatableFooterComponent;
}());

var NgxDatatableFooterModule = /** @class */ (function () {
    function NgxDatatableFooterModule() {
    }
    NgxDatatableFooterModule_1 = NgxDatatableFooterModule;
    NgxDatatableFooterModule.forRoot = function (footerOptions) {
        return {
            ngModule: NgxDatatableFooterModule_1,
            providers: [FooterOptionProvider(footerOptions)],
        };
    };
    var NgxDatatableFooterModule_1;
    NgxDatatableFooterModule = NgxDatatableFooterModule_1 = __decorate([
        NgModule({
            imports: [CommonModule, FormsModule, TranslateModule, NgxDatatableModule],
            declarations: [DatatablePagerComponent, DatatableFooterComponent],
            exports: [DatatablePagerComponent, DatatableFooterComponent],
            providers: [FooterConfigurationService],
        })
    ], NgxDatatableFooterModule);
    return NgxDatatableFooterModule;
}());

/*
 * Public API Surface of ngx-datatable-footer
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DatatableFooterComponent, DatatablePagerComponent, FooterConfigurationService, FooterOptionProvider, NgxDatatableFooterModule, Ngx_Datatable_Footer_Option, provideParent };
//# sourceMappingURL=ngx-datatable-footer.js.map
